# osds

## **PyTorch Object Storage Dataset**

To get an an iterable style object from large/out-of-memory CSV files stored in local file-system or Cloud storage platforms like Amazon-S3, Google cloud storage, and Azure blob storage.

![Documentation Status](https://readthedocs.org/projects/osds/badge/?version=latest)
![Build Status](https://travis-ci.com/Laay/osds.svg?branch=master)
![codecov](https://codecov.io/gh/Laay/osds/branch/master/graph/badge.svg)





